<?php

use Tygh\Http;
use Tygh\Registry;



const EU_API_EP = 'https://eu.api.wm.amdtelecom.net/api/endpoints';


function fn_install_routee() {
        $query = "CREATE TABLE IF NOT EXISTS `?:routee_shop_logs` (
                  `id` bigint(20) NOT NULL AUTO_INCREMENT,
                  `store_url` varchar(256) NOT NULL,
                  `log_type` tinyint(4) NOT NULL COMMENT '0 for error, 1 for success',
                  `event_type` tinyint(4) NOT NULL COMMENT '1 = auth, 2 = mass data, 3 = events',
                  `log_data` longtext NOT NULL,
                  `is_exported` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0 for no, 1 for yes',
                  `created_at` varchar(32) NOT NULL,
                  PRIMARY KEY (id)
                ) ENGINE=MyISAM DEFAULT CHARSET=latin1";

    db_query($query);

    getInitialUrls();
}

/**
 * @param $action
 * @param $user_data
 * @param $current_user_data
 * @return void
 */
function fn_routee_update_profile(&$action, &$user_data, &$current_user_data) {
    $event_name = ($action == 'add') ? 'CustomerAdd' : 'CustomerUpdate';
    writeLog('event', $event_name, 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        $event_data = array(
            'event' => $event_name,
            'uuid' => $routee_uuid,
            'data' => array(
                'customer' => array(
                    'id' => $user_data['user_id'],
                    'lastname' => $user_data['firstname'],
                    'firstname' => $user_data['lastname'],
                    'email' => $user_data['email'],
                ),
                'addresses' => array(
                    array(
                        'country' => $user_data['b_country_descr'],
                        'city' => $user_data['b_city'],
                        'address1' => $user_data['b_address'],
                        'postcode' => $user_data['b_zipcode'],
                        'phone' => $user_data['b_phone'],
                        'company' => $user_data['company'],
                    ),
                    array(
                        'country' => $user_data['s_country_descr'],
                        'city' => $user_data['s_city'],
                        'address1' => $user_data['s_address'],
                        'postcode' => $user_data['s_zipcode'],
                        'phone' => $user_data['s_phone'],
                        'company' => $user_data['company'],
                    ),
                )
            )
        );
        writeLog('event', $event_name, 200, "event ready for api call");
        Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', $event_name, 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', $event_name, $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $order_id
 * @param $action
 * @param $order_status
 * @param $cart
 * @param $auth
 * @return void
 */
function fn_routee_place_order(&$order_id, &$action, &$order_status, &$cart, &$auth) {
    writeLog('event', 'OrderAdd', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        $order_info = fn_get_order_info($order_id);

        $event_data = array(
            'event' => 'OrderAdd',
            'uuid' => $routee_uuid,
            'data' => array(
                'customer_id' => $order_info['user_id'],
                'order_details' => array(
                    'order_id' => $order_info['user_id'],
                    'order_status' => db_get_field('SELECT ?:status_descriptions.description FROM ?:status_descriptions LEFT JOIN ?:statuses ON ?:status_descriptions.status_id = ?:statuses.status_id WHERE ?:statuses.status = ?s AND ?:statuses.type = ?s AND ?:status_descriptions.lang_code = ?s', ($order_info['status'] == 'N') ? 'O' : $order_info['status'], 'O', CART_LANGUAGE),
                    'shipping_method' => db_get_field('SELECT ?:shipping_descriptions.shipping FROM ?:shipping_descriptions LEFT JOIN ?:shippings ON ?:shippings.shipping_id = ?:shippings.shipping_id WHERE ?:shippings.shipping_id = ?i AND ?:shipping_descriptions.lang_code = ?s', $order_info['shipping_ids'], CART_LANGUAGE),
                    'payment_method' => isset($order_info['payment_method']['payment']) ? $order_info['payment_method']['payment'] : '',
                    'total_price' => $order_info['total'],
                ),
                'customer' => array(
                    'id' => $order_info['user_id'],
                    'lastname' => $order_info['firstname'],
                    'firstname' => $order_info['lastname'],
                    'email' => $order_info['email'],
                ),
                'addresses' => array(
                    array(
                        'country' => $order_info['b_country_descr'],
                        'city' => $order_info['b_city'],
                        'address1' => $order_info['b_address'],
                        'postcode' => $order_info['b_zipcode'],
                        'phone' => $order_info['b_phone'],
                        'company' => $order_info['company'],
                    ),
                    array(
                        'country' => $order_info['s_country_descr'],
                        'city' => $order_info['s_city'],
                        'address1' => $order_info['s_address'],
                        'postcode' => $order_info['s_zipcode'],
                        'phone' => $order_info['s_phone'],
                        'company' => $order_info['company'],
                    ),
                )
            )
        );

        if (!empty($order_info['products'])) {
            foreach ($order_info['products'] as $v) {
                $event_data['data']['order_products'][] = array(
                    'product_id' => $v['product_id'],
                    'quantity' => $v['amount'],
                    'price' => $v['price'],
                    'discounted_price' => isset($v['extra']['discount']) ? $v['extra']['discount'] : 0,
                );
            }
        }
        writeLog('event', 'OrderAdd', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'OrderAdd', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'OrderAdd', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $status_to
 * @param $status_from
 * @param $order_info
 * @param $force_notification
 * @param $order_statuses
 * @param $place_order
 * @return void
 */
function fn_routee_change_order_status($status_to, $status_from, $order_info, $force_notification, $order_statuses, $place_order) {
    writeLog('event', 'OrderStatusUpdate', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        //Added support for tracking_number and shipping_method in OrderStatusUpdate event payload on 8th May 2020 by KapilH
        $tracking_number = db_get_field('SELECT tracking_number FROM ?:shipments WHERE shipment_id = ?i', $order_info['shipment_ids'][0] ?? 0);

        $event_data = array(
            'event' => 'OrderStatusUpdate',
            'uuid' => $routee_uuid,
            'data' => array(
                'customer_id' => $order_info['user_id'],
                'order_id' => $order_info['order_id'],
                'order_status' => db_get_field('SELECT ?:status_descriptions.description FROM ?:status_descriptions LEFT JOIN ?:statuses ON ?:status_descriptions.status_id = ?:statuses.status_id WHERE ?:statuses.status = ?s AND ?:statuses.type = ?s AND ?:status_descriptions.lang_code = ?s', $status_to, 'O', CART_LANGUAGE),
                'shipping_method' => db_get_field('SELECT ?:shipping_descriptions.shipping FROM ?:shipping_descriptions LEFT JOIN ?:shippings ON ?:shippings.shipping_id = ?:shippings.shipping_id WHERE ?:shippings.shipping_id = ?i AND ?:shipping_descriptions.lang_code = ?s', $order_info['shipping_ids'], CART_LANGUAGE),
                'tracking_number' => $tracking_number,
            )
        );
        writeLog('event', 'OrderStatusUpdate', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'OrderStatusUpdate', 200, "event finished");

        if ($status_to != 'P' && $status_to != 'C') {
            return;
        }

        $event_data = array(
            'event' => 'OrderPaymentConfirmed',
            'uuid' => $routee_uuid,
            'data' => array(
                'customer_id' => $order_info['user_id'],
                'order_id' => $order_info['order_id'],
            )
        );
        writeLog('event', 'OrderPaymentConfirmed', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'OrderPaymentConfirmed', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'OrderPaymentConfirmed | OrderStatusUpdate', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $product_data
 * @param $product_id
 * @param $lang_code
 * @param $create
 * @return void
 */
function fn_routee_update_product_post(&$product_data, &$product_id, &$lang_code, &$create) {
    $event_name = ($create) ? 'ProductAdd' : 'ProductUpdate';
    writeLog('event', $event_name, 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        $image_pair = fn_get_image_pairs($product_id, 'product', 'M', true, true, $lang_code);
        $product_options = fn_get_product_options($product_id);

        $event_data = array(
            'event' => $event_name,
            'uuid' => $routee_uuid,
            'data' => get_product_data($product_id, $product_data)
        );

        if (!empty($product_options)) {
            foreach ($product_options as $opt) {
                if (!empty($opt['variants'])) {
                    foreach ($opt['variants'] as $var) {
                        $event_data['data']['product_options'][] = array(
                            'option_id' => $opt['option_id'],
                            'option_name' => $opt['option_name'],
                            'varian_name' => $var['variant_name'],
                            'price_modifier' => $var['modifier'],
                        );
                    }
                }
            }
        }

        if (!empty($product_data['category_ids'])) {
            foreach ($product_data['category_ids'] as $v) {
                $event_data['data']['categories'][] = fn_get_category_name($v, $lang_code);
            }
        }
        writeLog('event', $event_name, 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', $event_name, 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', $event_name, $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $product_id
 * @param $product_data
 * @return array
 */
function get_product_data($product_id, $product_data) {
    return array(
        'product_id' => $product_id,
        'name' => $product_data['product'],
        'description' => strip_tags($product_data['full_description']),
        'short_description' => strip_tags($product_data['short_description']),
        'stock_quantity' => $product_data['amount'],
        'price' => $product_data['price'],
        'image_link' => (!empty($image_pair)) ? $image_pair['detailed']['image_path'] : '',
        'product_link' => fn_url('products.view?product_id='.$product_id, 'C'),
    );
}

/**
 * @param $new_amount
 * @param $product_id
 * @param $cart_id
 * @param $tracking
 * @param $notify
 * @return void
 */
function fn_routee_update_product_amount(&$new_amount, &$product_id, &$cart_id, &$tracking, &$notify) {
    writeLog('event', 'ProductStockUpdate', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        $event_data = array(
            'event' => 'ProductStockUpdate',
            'uuid' => $routee_uuid,
            'data' => array(
                'product_id' => $product_id,
                'stock_quantity' => $new_amount,
            )
        );
        writeLog('event', 'ProductStockUpdate', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'ProductStockUpdate', 200, "event finished");

        if ($new_amount > 0) {
            return;
        }

        $event_data = array(
            'event' => 'ProductOutOfStock',
            'uuid' => $routee_uuid,
            'data' => array(
                'product_id' => $product_id,
            )
        );
        writeLog('event', 'ProductOutOfStock', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'ProductOutOfStock', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'ProductStockUpdate | ProductOutOfStock', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $product_data
 * @param $wishlist
 * @param $auth
 * @return void
 */
function fn_routee_pre_add_to_wishlist(&$product_data, &$wishlist, &$auth) {
    writeLog('event', 'WishlistAdd', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid) || empty($product_data)) {
            return;
        }

        foreach ($product_data as $v) {

            $event_data = array(
                'event' => 'WishlistAdd',
                'uuid' => $routee_uuid,
                'data' => array(
                    'product_id' => $v['product_id'],
                    'customer_id' => $auth['user_id'],
                )
            );
            writeLog('event', 'WishlistAdd', 200, "event ready for api call");
            $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
            writeLog('event', 'WishlistAdd', 200, "event finished");
        }
    }catch (Exception $exception){
        writeLog('event', 'WishlistAdd', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $wishlist
 * @param $wishlist_id
 * @return void
 */
function fn_routee_delete_wishlist_product(&$wishlist, &$wishlist_id) {
    writeLog('event', 'WishlistDelete', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid) || !isset($wishlist['products'][$wishlist_id])) {
            return;
        }

        $event_data = array(
            'event' => 'WishlistDelete',
            'uuid' => $routee_uuid,
            'data' => array(
                'product_id' => $wishlist['products'][$wishlist_id]['product_id'],
                'customer_id' => $_SESSION['auth']['user_id'],
            )
        );
        writeLog('event', 'WishlistDelete', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'WishlistDelete', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'WishlistDelete', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $cart
 * @param $user_id
 * @param $type
 * @param $user_type
 * @return void
 */
function fn_routee_save_cart_content_post(&$cart, &$user_id, &$type, &$user_type) {
    writeLog('event', 'CartUpdate', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid) || $type != 'C') {
            return;
        }

        $event_data = array(
            'event' => 'CartUpdate',
            'uuid' => $routee_uuid,
            'data' => array(
                'customer_id' => $_SESSION['auth']['user_id'],
                'cart_products' => array()
            )
        );

        if (isset($cart['products']) && !empty($cart['products'])) {
            foreach ($cart['products'] as $v) {
                $event_data['data']['cart_products'][] = array(
                    'product_id' => $v['product_id'],
                    'quantity' => $v['amount'],
                );
            }
        }
        writeLog('event', 'CartUpdate', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'CartUpdate', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'CartUpdate', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $subscriber_id
 * @param $user_list_ids
 * @param $subscriber
 * @param $params
 * @return void
 */
function fn_routee_newsletters_update_subscriptions_post(&$subscriber_id, &$user_list_ids, &$subscriber, &$params) {
    writeLog('event', 'Newsletter', 200, "event triggered");
    try {
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid) || empty($subscriber['email'])) {
            return;
        }

        $event_data = array(
            'event' => 'Newsletter',
            'uuid' => $routee_uuid,
            'data' => array(
                'customer_id' => $_SESSION['auth']['user_id'],
                'email' => $subscriber['email'],
                'subscription' => 'true',
            )
        );
        writeLog('event', 'Newsletter', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        writeLog('event', 'Newsletter', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'Newsletter', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $params
 * @param $fields
 * @param $sortings
 * @param $condition
 * @param $join
 * @param $sorting
 * @param $group_by
 * @param $lang_code
 * @param $having
 * @return void
 */
function fn_routee_get_products(&$params, &$fields, &$sortings, &$condition, &$join, &$sorting, &$group_by, &$lang_code, &$having) {
	if(isset($params['q'])){
		writeLog('event', 'Search', 200, "event triggered");
		try {
			$routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

			if (empty($routee_uuid) || !isset($params['q']) || empty($params['q'])) {
				return;
			}

			$user_id = $_SESSION['auth']['user_id'];
			$email = $user_id > 0 ? $_SESSION['cart']['user_data']['email'] : '';
			$phone = $user_id > 0 ? $_SESSION['cart']['user_data']['phone'] : '';

			$event_data = array(
				'event' => 'Search',
				'uuid' => $routee_uuid,
				'data' => array(
					'customer_id' => $user_id,
					'search_string' => $params['q'],
					'email' => $email,
					'phone' => $phone,
				)
			);
			writeLog('event', 'Search', 200, "event ready for api call");
			$return = Http::post(getDynamicUrl('event'), json_encode($event_data));
			writeLog('event', 'Search', 200, "event finished");
		}catch (Exception $exception){
			writeLog('event', 'Search', $exception->getCode(), $exception->getMessage());
		}
	}
}

/**
 * @return string
 */
function fn_get_account_creation_notice() {
    return __('routee.account_creation_notice');
}

/**
 * @return string
 */
function fn_get_export_log_data_notice() {
    return __('routee.export_log_data_notice');
}

/**
 * @return string
 */
function fn_get_export_log_data_notice_csv() {
    return __('routee.export_log_data_notice_csv');
}

/**
 * @return void
 */
function fn_uninstall_routee() {
    writeLog('event', 'Uninstall', 200, "event triggered");
    try {
        uninstallEu();
        $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');

        if (empty($routee_uuid)) {
            return;
        }

        $event_data = array(
            'event' => 'Uninstall',
            'uuid' => $routee_uuid,
            'data' => array()
        );
        writeLog('event', 'Uninstall', 200, "event ready for api call");
        $return = Http::post(getDynamicUrl('event'), json_encode($event_data));
        db_query('DELETE FROM ?:common_descriptions WHERE object_holder = ?s', 'routee_uuid');
        writeLog('event', 'Uninstall', 200, "event finished");
    }catch (Exception $exception){
        writeLog('event', 'Uninstall', $exception->getCode(), $exception->getMessage());
    }
}

/**
 * @param $mode
 * @param $event
 * @param $code
 * @param $msg
 * @return void
 */
function writeLog( $mode, $event, $code, $msg ) {
    try {
        $shop = Registry::get('config.current_location');
        $data = array(
            'mode' => $mode,
            'event' => $event,
            'code' => $code,
            'exception_message' => $msg
        );
        $logType = $code !== 200 ? 0 : 1;
		
		$eventType = eventType($mode);
        saveLogs($eventType, $data, $shop, $logType);
        sendLog($shop,$event, $logType,$data);
    }catch (Exception $exception){}
}

/**
 * @param $eventType
 * @param $data
 * @param $shop
 * @param $logType
 * @return void
 */
function saveLogs($eventType, $data, $shop, $logType){
    try {
        $isExported = 0;
        $data = json_encode($data);
        $time = gmdate('d-m-Y H:i:s');
        db_query("INSERT INTO ?:routee_shop_logs (store_url, log_type,event_type,log_data,is_exported,created_at) VALUES ('{$shop}','{$logType}','{$eventType}','{$data}','{$isExported}','{$time}')");
    }catch (Exception $exception){}
}

/**
 * @param $shop
 * @param $event
 * @param $logType
 * @param $data
 * @return void
 */
function sendLog($shop, $event, $logType, $data){
    try {
        if (!$logType){
            $routee_uuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
            $postArr = array(
                'siteUrl' => $shop,
                'uuid' => $routee_uuid,
                'event_name' => $event,
                'log_type' => 'failure',
                'log_data' => $data,
                'created_at' => gmdate('d-m-Y H:i:s'),
                'platform' => "CSCart"
            );
            Http::post(getDynamicUrl("logs"),json_encode($postArr));
        }
    }catch (Exception $exception){}
}

/**
 * @param $event
 * @return int
 */
function eventType($event) {
	$type = 0;

	switch ($event) {
		case "auth":
			$type = 1;
			break;
		case "mass":
			$type = 3;
			break;
		case "event":
			$type = 2;
			break;
	}

	return $type;
}

function getPluginVersion(){
    return db_get_field('SELECT version FROM ?:addons WHERE addon = ?s', 'routee');
}


/**
 * @param $url
 * @param $type
 * @return void
 */
function saveUrl($url, $type)
{
    $_data = array(
        'object_id' => '1',
        'lang_code' => 'en',
        'description' => trim($url),
        'object_holder' => 'routee_'.$type
    );
    db_query('REPLACE INTO ?:common_descriptions ?e', $_data);
}

/**
 * @param $postData
 * @param $uri
 * @return void
 */
function saveAllUrls($postData, $uri)
{
    $urls = fetchUrls($postData, $uri);
    compileAndSave($urls);
}

/**
 * @param $urls
 * @return void
 */
function compileAndSave($urls)
{
    if (count($urls) > 0){
        foreach ($urls as $url) {
            saveUrl($url['url'], $url['type']);
        }
    }
}

/**
 * @param $postData
 * @param $uri
 * @return null
 */
function fetchUrls($postData, $uri)
{
    $url = EU_API_EP . $uri;
    $result = Http::post($url, $postData);

    if (!empty($result)) {
        $decoded = json_decode($result, true);
        return !empty($decoded['data']) ? $decoded['data'] : [];
    }

    return null;
}


/**
 * @param $uuid
 * @param $urlsData
 * @param $isSuccess
 */
function handleRouteeEndpoint($uuid, $urlsData, $isSuccess)
{
    $currentUuid = db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', 'routee_uuid', 'en');
    if (!empty($currentUuid)){
        if (!empty($isSuccess) && !empty($uuid) && !empty($urlsData) && $uuid == $currentUuid){
            compileAndSave($urlsData);
            return true;
        }
    }

    return false;
}

/**
 * @return array
 */
function commonEndpointPayload()
{
    $userInfo = (!empty($_SESSION) && !empty($_SESSION['auth']['user_id'])) ? fn_get_user_info($_SESSION['auth']['user_id']) : null;

    return [
        "store_url" => Registry::get('config.current_location'),
        "platform" => "CSCart",
        "plugin_version" => getPluginVersion(),
        "platform_version" => PRODUCT_VERSION,
        'user_id' => $userInfo['user_id'] ?? "",
        "email" => $userInfo["email"] ?? ""
    ];
}

/**
 * @param $uuid
 * @return void
 */
function saveUrlAuth($uuid)
{
    $postData = commonEndpointPayload();
    $postData["store_uuid"] = $uuid;
    $postData["store_callback_url"] = Registry::get('config.current_location').'/api.php?version=2&dispatch=routee_api.post';
    saveAllUrls($postData, '/save_callback');
}

function getDynamicUrl($type){
    $type = 'routee_'.$type;
    return db_get_field('SELECT description FROM ?:common_descriptions WHERE object_holder = ?s AND lang_code = ?s', $type, 'en');
}

function getInitialUrls(){
    if (empty(getDynamicUrl('auth'))){
        $postData = commonEndpointPayload();
        saveAllUrls($postData, '/get');
    }
}

function removeUrlsFromSession(){
    $urls = [
        'auth',
        'logs',
        'event',
        'data'
    ];
    foreach ($urls as $url) {
        db_query('DELETE FROM ?:common_descriptions WHERE object_holder = ?s', 'routee_'.$url);
    }
}

function uninstallEu(){
    removeUrlsFromSession();
    $url = EU_API_EP . '/uninstall';
    $postedData['store_url'] = Registry::get('config.current_location');
    $response = Http::post($url, $postedData);
}

function fn_routee_api_handle_request(){
    $data = json_decode(file_get_contents('php://input'), true);
    $uuid = $data["uuid"];
    $urlsData = $data["data"];
    $isSuccess = $data["success"];

    $response = handleRouteeEndpoint($uuid, $urlsData, $isSuccess);
    if ($response) {
        $result = array('success' => true, 'message' => 'Endpoints updated.');
    }else{
        $result = array('success' => false, 'message' => 'Invalid information.');
    }
    echo json_encode($result);
    exit();
}
